@@ -30,7 +30,8 @@
 
     Written by      Richard Gooch   30-APR-2000: Copied from devfsd.c
 
-    Last updated by Richard Gooch   30-APR-2000
+    Last updated by Richard Gooch   10-JUN-2000: Added compatibility entries
+  for ISDN BRI driver. Thanks to Xuan Baldauf <xuan--lkml@baldauf.org>.
 
 
 */
@@ -83,6 +84,7 @@ static struct translate_struct translate_table[] =
     {"cuf/",       "cuf%s"},
     {"vc/",        "tty%s"},
     {"misc/",      NULL},
+    {"isdn/",      NULL},
     {NULL,         NULL}
 };
 
